@@ -101,7 +101,7 @@ function(angle,y,period=24,na.rm=na.rm) {
     cor.dat <- cor(dat.df,use="pairwise")
     beta1 <- (cor.dat[3,1] - cor.dat[3,2] * cor.dat[1,2])/(cor.dat[1,1]-cor.dat[1,2]^2)  
     beta2 <- (cor.dat[3,2] - cor.dat[3,1] * cor.dat[1,2])/(cor.dat[1,1]-cor.dat[1,2]^2)
-     
+    #note, these are standardized beta weights 
    #  phase <- ( sign(beta2) *acos( beta1/sqrt(beta1^2 + beta2^2)))*p2/pi #this is in hours
      phase <- atan2(beta2,beta1)  #in radians
      intercept <- cos(phase)   #the value at time 0
@@ -111,7 +111,7 @@ function(angle,y,period=24,na.rm=na.rm) {
      sdy <-  sd(y,na.rm=na.rm)
      meany <- mean(y,na.rm=na.rm)
      #amp <- r *sdy/.7223
-     amp <- sqrt(beta1^2 + beta2^2) #see Chow 2009 among others
+     amp <- sqrt(beta1^2 + beta2^2) #see Chow 2009 among others -- note we are finding the standardized amp
      intercept <- intercept * amp * sdy  + meany
      #amp <- r * sd(y,na.rm=TRUE)/sd(cos(angle[,1]),na.rm=TRUE)
     #R <- sqrt(cor.dat[3,1]*beta1 + cor.dat[3,2]*beta2)  #these are identical
@@ -123,8 +123,8 @@ return(fit)
 
   
 "cosinor.plot" <- 
-  function(angle,x=NULL,data = NULL,IDloc=NULL,ID=NULL,hours=TRUE,period=24,na.rm=TRUE,ylim=NULL,ylab="observed",xlab="time (double plotted)",main="Cosine fit",...) 
-  {main <- paste("ID = ",ID," ",x)
+  function(angle,x=NULL,data = NULL,IDloc=NULL,ID=NULL,hours=TRUE,period=24,na.rm=TRUE,ylim=NULL,ylab="observed",xlab="Time (double plotted)",main="Cosine fit",add=FALSE,multi=FALSE,typ="l",...) {
+  if(!multi) {main <- paste("ID = ",ID," ",x)}
 
   if(!is.null(data)) {
      if(is.matrix(data)) data <- data.frame(data)
@@ -147,19 +147,26 @@ return(fit)
      }
   
 if(hours) { angle <- angle*2*pi/24 }
-xx <- 1:96
+ xx <- 1:96
+fit <- cosinor1(angle, x = x[2], period = period, na.rm = na.rm)
+m.resp <- mean(x[, 2], na.rm = TRUE)
+s.resp <- sd(x[, 2], na.rm = TRUE)
+ sd.time <- sd(cos(angle[, 1]), na.rm = TRUE)
 
-#fit <- cosinor1(angle=x[1],x=x[2],code,drop=FALSE],period=period,na.rm=na.rm)
-fit <- cosinor1(angle,x=x[2],period=period,na.rm=na.rm)
-m.resp <- mean(x[,2],na.rm=TRUE)
-s.resp <- sd(x[,2],na.rm=TRUE)
-sd.time <- sd(cos(angle[,1]),na.rm=TRUE)
 if(missing(ylim)) ylim=c(min(x[,2],(m.resp - fit[1,3]),na.rm=na.rm),max(x[,2],(m.resp + fit[1,3]),na.rm=na.rm))
-main <- paste(main," ",round(fit[1,1],2))
-# plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ="l",ylim=ylim,...)
-# plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*fit[1,3]*s.resp+ m.resp,typ="l",ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)
-plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ="l",ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)
-points(c(x[,1],x[,1] + 24),rep(x[,2],2))
+if(!multi | !missing(main)){main <- paste(main," ",round(fit[1,1],2)) } else {main=main}
+
+# plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ=typ,ylim=ylim,...)
+# plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*fit[1,3]*s.resp+ #m.resp,typ="l",ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)
+#plot the lines first
+if(!add) 
+{plot(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ=typ,ylim=ylim,ylab=ylab,xlab=xlab,main=main,...)  } else {
+points(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ=typ,ylim=ylim,ylab=ylab,xlab=xlab,main=main,...) }
+
+
+if(!multi) {
+points(c(x[,1],x[,1] + 24),rep(x[,2],2),...)} else {points(xx/2,cos((xx/2-fit[1,1])*pi/12)*s.resp*fit[1,2]/.707+ m.resp,typ="l",...)}
+ 
 
 #this draws the first fitted variable
   }
