@@ -1,13 +1,15 @@
+
+#modified October 9, 2015 to add the NA option 
 #January 27, 2014  added fa.congruence to clean up calls
 
 #modified March 12 to allow for a list of factor solutions
 
 "factor.congruence" <-
-function (x,y=NULL,digits=2) {
-   fa.congruence(x=x,y=y,digits=digits) }
+function (x,y=NULL,digits=2,use=NULL) {
+   fa.congruence(x=x,y=y,digits=digits,use=use) }
 
 "fa.congruence" <-
- function (x,y=NULL,digits=2) {
+ function (x,y=NULL,digits=2,use=NULL) {
 if(is.null(y)&& is.list(x)) {
 	n <- length(x)
 		for (i in 1:n) {
@@ -28,9 +30,26 @@ if(length(class(y)) > 1)  { if(class(y)[2] =='omega')  {y <- y$schmid$sl
  if (!is.matrix(x)) {if(!is.null(x$loadings)) {x <- x$loadings} else {x <- as.matrix(x)}   }
    if (!is.matrix(y)) {if(!is.null(y$loadings))  { y <- y$loadings } else {y <- as.matrix(y)}}
    }
+   
+   if(any(is.na(x) | any(is.na(y) ))) {warning("Some loadings were missing.")
+        if(!is.null(use)) {message("Analysis is  done on complete cases") 
+     if(any(is.na(x))) {
+        xc <- x[complete.cases(x),]
+        y <- y[complete.cases(x),]
+        x <- xc
+        }
+     if (any(is.na(y))) {
+       yc <- y[complete.cases(y),]
+       x <- x[complete.cases(y),]
+       y <- yc}
+     }
+     else {warning("Check your data or rerun with the  use = complete option")}
+     }
+     
+   
       
-  nx<- dim(x)[2]
-  ny<- dim(y)[2]
+  nx <- dim(x)[2]
+  ny <- dim(y)[2]
   cross<- t(y) %*% x   #inner product will have dim of ny * nx
    sumsx<- sqrt(1/diag(t(x)%*%x))   
    sumsy<- sqrt(1/diag(t(y)%*%y)) 
