@@ -43,7 +43,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
     eigens <- eigen(r)    #call the eigen value decomposition routine
     result$values <- eigens$values
     eigens$values[ eigens$values < .Machine$double.eps] <-  .Machine$double.eps  #added May 14, 2009 to fix case of singular matrices
-    loadings <- eigens$vectors %*% sqrt(diag(eigens$values))
+    loadings <- eigens$vectors %*% sqrt(diag(eigens$values,nrow=length(eigens$values))) #added May 2, 2016 for the weird case of a single variable with covariance > 1
    
    if(nfactors > 0) {loadings <- loadings[,1:nfactors]} else {nfactors <- n}
    if (nfactors > 1) {communalities <- rowSums(loadings^2)} else {communalities <- loadings^2 }
@@ -70,6 +70,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
 if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" | rotate =="targetT" | rotate =="bifactor"   | rotate =="TargetT"|
                        rotate =="equamax"| rotate =="varimin"|rotate =="specialT" | rotate =="Promax"  | rotate =="promax"| rotate =="cluster" |rotate == "biquartimin" |rotate == "TargetQ"  |rotate =="specialQ" ) {
 Phi <- NULL 
+ colnames(loadings) <- paste("RC",1:nfactors,sep='')   #for rotated component
 switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psych
   varimax = {rotated <- stats::varimax(loadings)  #varimax is from stats, the others are from GPArotation 
    			         loadings <- rotated$loadings
@@ -147,6 +148,7 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
      				 Phi <- ob$Phi
      				 rot.mat <- t(solve(pro$Th))})
      } else {
+      colnames(loadings) <- paste("TC",1:nfactors,sep='') #for transformed components
      #The following oblique cases all use GPArotation			                
      if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ"  |rotate == "targetQ"  ) {
      				if (!requireNamespace('GPArotation')) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
@@ -159,7 +161,8 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
      				loadings <- ob$loadings
      				 Phi <- ob$Phi
      				  rot.mat <- t(solve(ob$Th))}
-     		                             } else {message("Specified rotation not found, rotate='none' used")}
+     		                             } else {message("Specified rotation not found, rotate='none' used")
+     		                              colnames(loadings) <- paste("PC",1:nfactors,sep='')  }  #not rotated
      	 }
      	} 
      	 }
@@ -177,7 +180,7 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
      colnames(loadings) <- c.names
     if(!is.null(Phi)) {Phi <- diag(signed) %*% Phi %*% diag(signed) 
                      colnames(Phi) <- rownames(Phi) <- c.names} 
-   
+    
     
     
      class(loadings) <- "loadings"
@@ -215,9 +218,14 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
                        result$Structure <- loadings %*% Phi} else {result$Structure <- loadings
                        }
     
-    if(scores && raw) {result$scores <- factor.scores(scale(x.matrix),result$Structure,method=method)  # method = method added Nov 20, 2011
-                result$weights<- result$scores$weights
-                result$scores <- result$scores$scores}
+    if(scores && raw) {
+             # if(covar) { if(!is.null(Phi)) {Phi <- Phi %*% diag(sqrt(diag(t(loadings) %*% loadings))) } }
+               result$weights <- solve(r,result$Structure)
+               result$scores <- scale(x.matrix,scale=!covar) %*% result$weights}
+             
+             #   result$scores <- factor.scores(scale(x.matrix,scale=!covar),result$Structure,Phi=Phi,method=method,rho=r)  # method = method added Nov 20, 2011
+              #  result$weights<- result$scores$weights
+             #   result$scores <- result$scores$scores}
     return(result)
    }
   
@@ -236,4 +244,6 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
   #modified June 19, 2012 to fix a missing value problem reported by Neil Stewart
   #modified February 9, 2013 to label the type of rotation/transformation (as is documented but not implemented)
   #modified February 25, 2013 to make scores=TRUE the default 
-  #modified 1/16/14 to output the structure matrix 
\ No newline at end of file
+  #modified 1/16/14 to output the structure matrix 
+  #modified 8/15 to add rot.mat to all rotations
+  #modified 9/3/15 to label rotated PCs as RC  and transformed as TC -- perhaps this was dropped out while fixing rotations?
\ No newline at end of file
